<?php # lang_cs.inc.php 1381.1 2009-08-15 10:30:56 VladaAjgl $

/**
 *  @version 1381.1
 *  @author Vladimr Ajgl <vlada@ajgl.cz>
 *  EN-Revision: Revision of lang_en.inc.php
 *  @author Vladimr Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/06/14
 *  @author Vladimr Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/08/15
 */

@define('PLUGIN_SHOUTBOX_NAME',                 'Vkink');
@define('PLUGIN_SHOUTBOX_DELETE',               'Smazat');
@define('PLUGIN_SHOUTBOX_SUBMIT',               'Poli vkik do svta');
@define('PLUGIN_SHOUTBOX_BLAHBLAH',             'Zobrazuje okno pro vkiky, tzn. komente, kter nejsou poslan ke konkrtnmu pspvku');
@define('PLUGIN_SHOUTBOX_WORDWRAP',             'Zalamovn slov');
@define('PLUGIN_SHOUTBOX_WORDWRAP_BLAHBLAH',    'Po kolika slovech se m vkik zalomit? (Pednastaveno: 30)');
@define('PLUGIN_SHOUTBOX_MAXCHARS',             'Maximln poet znak');
@define('PLUGIN_SHOUTBOX_MAXCHARS_BLAHBLAH',    'Kolik znak z kadho pspvku m bt nanejv zobrazeno? (Pednastaveno: 120)');
@define('PLUGIN_SHOUTBOX_MAXENTRIES',           'Poet vkik');
@define('PLUGIN_SHOUTBOX_MAXENTRIES_BLAHBLAH',  'Kolik poslednch vkik se m zobrazovat? (Pednastaveno: 15)');
@define('GENERAL_PLUGIN_BOX_COLS',              'Sloupce shoutboxu');
@define('GENERAL_PLUGIN_BOX_COLS_BLAHBLAH',     'Poet sloupc pole pro zadvn vkik');
@define('GENERAL_PLUGIN_BOX_ROWS',              'Poet dek shoutboxu');
@define('GENERAL_PLUGIN_BOX_ROWS_BLAHBLAH',     'Poet dek pole pro zadvn vkik');